#include <ESP8266WiFi.h>
#include <WiFiClient.h>
#include <ESP8266WiFiMulti.h> 
#include <ESP8266mDNS.h>
#include <ESP8266WebServer.h>

ESP8266WiFiMulti wifiMulti;     // Create an instance of the ESP8266WiFiMulti class, called 'wifiMulti'

ESP8266WebServer server(80);    // Create a webserver object that listens for HTTP request on port 80

const int led = 2;
const int grijac = 0;

void handleRoot();              // function prototypes for HTTP handlers
void handleLogin();
void handleLED();
void handleGrijac();
void handleNotFound();
String HTMLResponse();  
void heaterStatusHTML(); 

void setup(void){
  Serial.begin(115200);         // Start the Serial communication to send messages to the computer
  delay(10);
  Serial.println('\n');
  pinMode(led, OUTPUT);

  wifiMulti.addAP("Ime wifi mreze", "sifra");   // add Wi-Fi networks you want to connect to
 
  Serial.println("Connecting ...");
  int i = 0;
  while (wifiMulti.run() != WL_CONNECTED) { // Wait for the Wi-Fi to connect: scan for Wi-Fi networks, and connect to the strongest of the networks above
    delay(250);
    Serial.print('.');
  }
  Serial.println('\n');
  Serial.print("Connected to ");
  Serial.println(WiFi.SSID());               // Tell us what network we're connected to
  Serial.print("IP address:\t");
  Serial.println(WiFi.localIP());            // Send the IP address of the ESP8266 to the computer

  if (MDNS.begin("esp8266")) {              // Start the mDNS responder for esp8266.local
    Serial.println("mDNS responder started");
  } else {
    Serial.println("Error setting up MDNS responder!");
  }

  server.on("/", HTTP_GET, handleRoot);        // Call the 'handleRoot' function when a client requests URI "/"
  server.on("/login", HTTP_POST, handleLogin); // Call the 'handleLogin' function when a POST request is made to URI "/login"
  server.on("/LED", HTTP_POST, handleLED);  // Call the 'handleLED' function when a POST request is made to URI "/LED"
  server.on("/action_page.php", HTTP_POST, handleLED);
  server.onNotFound(handleNotFound);           // When a client requests an unknown URI (i.e. something other than "/"), call function "handleNotFound"

  server.begin();                            // Actually start the server
  Serial.println("HTTP server started");
}

void loop(void){
  server.handleClient();                     // Listen for HTTP requests from clients
}

void handleRoot() {                          // When URI / is requested, send a web page with a button to toggle the LED
  server.send(200, "text/html", "<h1>Pametni termostat</h1><p>Unesite korisnicko ime i lozinku</p><form action=\"/login\" method=\"POST\"><input type=\"text\" name=\"username\" placeholder=\"Username\"></br><input type=\"password\" name=\"password\" placeholder=\"Password\"></br><input type=\"submit\" value=\"Login\"></form><p>Filip Sklebar, SPVP 2018.</p>");
}

void handleLogin() {                         // If a POST request is made to URI /login
  if( ! server.hasArg("username") || ! server.hasArg("password") 
      || server.arg("username") == NULL || server.arg("password") == NULL) { // If the POST request doesn't have username and password data
    server.send(400, "text/plain", "400: Invalid Request");         // The request is invalid, so send HTTP status 400
    return;
  }
  if(server.arg("username") == "Filip" && server.arg("password") == "filip123") { // If both the username and the password are correct
  "<head>"
  "<meta http-equiv=\"refresh\" content=\"20\">"
  "<link rel=\"stylesheet\" href=\"styles.css\">"
  "<meta charset=\"UTF-8\">"
  "<script src=\"https://ajax.googleapis.com/ajax/libs/jquery/1.12.2/jquery.min.js\"></script>"
  "</head>"
  "<body>"
  "<header>"
  "<h1>Pametni termostat</h1>"
  "</header>"
  "<vel>"
  "<p>""Temperatura u prostoriji iznosi: "
  "<boja><b>" + heaterStatusHTML() + "<sup> o</sup>""C" "</b></boja></p>"
  "<p id=\"status\">" 
  "</p>"
  "</vel>"
  "<br>"
  "<legend>Zeljena temperatura:</legend>"
  "<form action="/action_page.php>""
  "oninput="x.value=parseInt(b.value)">"
  "<input type="number" id="b" name="b" value="25">"  
  "<p>Trenutno odabrana temperatura: <output name="x" for="b"></output> °C</p>"
  "<div>Ukljuci grijac<razmak_lijevo></razmak_lijevo><razmak_lijevo></razmak_lijevo><label class=\"switch\">"
  "<input type=\"checkbox\" class=\"mode\" "+modeDescription()+">"
  "<div class=\"slider round\"></div>"
  "</label></div>"
  "<br>"
  "<button type=\"button\" onclick=\"setHeaterStatus(\'on\')\">Ukljuci</button>""<razmak_lijevo>"
  "</razmak_lijevo>""<button type=\"button\" onclick=\"setHeaterStatus(\'off\')\">Iskljuci</button>"
  "<script>"
  "    function setHeaterStatus(newStatus) {"
  "      var xhttp = new XMLHttpRequest();"
  "      xhttp.onreadystatechange = function() {"
  "        if (xhttp.readyState == 4 && xhttp.status == 200) {"
  "</fieldset>"
  "<br>"
  "<input type="submit" value="Ukljuci grijac">"
  "</form>"
  "</script>"
  "<p>Filip Sklebar, SPVP 2018.</p>"
  "</body>"
  "</html>";
  }
  } else {                                                                              // Username and password don't match
    server.send(401, "text/plain", "401: Unauthorized");
 }
}
void handleLED() {                          // If a POST request is made to URI /LED
  digitalWrite(led,!digitalRead(led));      // Change the state of the LED
  server.sendHeader("Location","/LED");        // Add a header to respond with a new location for the browser to go to the home page again
  server.send(303);                         // Send it back to the browser with an HTTP status 303 (See Other) to redirect
}
void handleGrijac() {                          // If a POST request is made to URI /LED
  digitalWrite(grijac,!digitalRead(grijac));      // Change the state of the LED
  server.sendHeader("Location","/grijac");        // Add a header to respond with a new location for the browser to go to the home page again
  server.send(303);                         // Send it back to the browser with an HTTP status 303 (See Other) to redirect
}
void handleNotFound(){
  server.send(404, "text/plain", "404: Not found"); // Send HTTP status 404 (Not Found) when there's no handler for the URI in the request
}


